@@ -148,6 +148,7 @@ module ChefZero
 
       DEFAULT_ORG_SPINE = {
         'clients' => {},
+        'cookbook_artifacts' => {},
         'cookbooks' => {},
         'data' => {},
         'environments' => %w(_default),
@@ -162,7 +163,7 @@ module ChefZero
         'users' => {},
 
         'org' => {},
-        'containers' => %w(clients containers cookbooks data environments groups nodes roles sandboxes policies cookbook_artifacts),
+        'containers' => %w(clients containers cookbook_artifacts cookbooks data environments groups nodes policies policy_groups roles sandboxes),
         'groups' => %w(admins billing-admins clients users),
         'association_requests' => {}
       }
@@ -281,7 +282,7 @@ module ChefZero
               'delete' => { 'groups' => %w(admins) },
               'grant'  => { 'groups' => %w(admins) },
             }
-          when 'containers/cookbooks', 'containers/environments', 'containers/roles'
+          when 'containers/environments', 'containers/roles', 'containers/policy_groups', 'containers/policies'
             {
               'create' => { 'groups' => %w(admins users) },
               'read'   => { 'groups' => %w(admins users clients) },
@@ -289,7 +290,7 @@ module ChefZero
               'delete' => { 'groups' => %w(admins users) },
               'grant'  => { 'groups' => %w(admins) },
             }
-          when 'containers/cookbooks', 'containers/data'
+          when 'containers/cookbooks', 'containers/cookbook_artifacts', 'containers/data'
             {
               'create' => { 'groups' => %w(admins users clients) },
               'read'   => { 'groups' => %w(admins users clients) },
@@ -439,7 +440,7 @@ module ChefZero
         when 4
           return path[0] == 'organizations' && (
             (path[2] == 'acls' && path[1] != 'root') ||
-            %w(cookbooks data).include?(path[2]))
+            %w(cookbooks cookbook_artifacts data policies policy_groups).include?(path[2]))
         else
           return false
         end
