@@ -1,4 +1,4 @@
-require 'json'
+require 'ffi_yajl'
 require 'chef_zero/rest_base'
 require 'chef_zero/chef_data/data_normalizer'
 require 'chef_zero/chef_data/acl_path'
@@ -20,7 +20,7 @@ module ChefZero
         if !acl_path
           raise RestErrorResponse.new(404, "Object not found: #{build_uri(request.base_uri, request.rest_path)}")
         end
-        acls = JSON.parse(get_data(request, acl_path), :create_additions => false)
+        acls = FFI_Yajl::Parser.parse(get_data(request, acl_path), :create_additions => false)
         acls = ChefData::DataNormalizer.normalize_acls(acls)
         json_response(200, acls)
       end
