@@ -1,4 +1,4 @@
-require 'json'
+require 'ffi_yajl'
 require 'chef_zero/rest_base'
 
 module ChefZero
@@ -6,7 +6,7 @@ module ChefZero
     # /authenticate_user
     class AuthenticateUserEndpoint < RestBase
       def post(request)
-        request_json = JSON.parse(request.body, :create_additions => false)
+        request_json = FFI_Yajl::Parser.parse(request.body, :create_additions => false)
         name = request_json['username']
         password = request_json['password']
         begin
@@ -14,7 +14,7 @@ module ChefZero
         rescue ChefZero::DataStore::DataNotFoundError
           raise RestErrorResponse.new(401, "Bad username or password")
         end
-        user = JSON.parse(user, :create_additions => false)
+        user = FFI_Yajl::Parser.parse(user, :create_additions => false)
         user = ChefData::DataNormalizer.normalize_user(user, name, [ 'username' ], server.options[:osc_compat])
         if user['password'] != password
           raise RestErrorResponse.new(401, "Bad username or password")
