@@ -1,4 +1,4 @@
-require 'json'
+require 'ffi_yajl'
 require 'chef_zero/endpoints/cookbooks_base'
 
 module ChefZero
@@ -6,12 +6,12 @@ module ChefZero
     # /environment/NAME/recipes
     class EnvironmentRecipesEndpoint < CookbooksBase
       def get(request)
-        environment = JSON.parse(get_data(request, request.rest_path[0..3]), :create_additions => false)
+        environment = FFI_Yajl::Parser.parse(get_data(request, request.rest_path[0..3]), :create_additions => false)
         constraints = environment['cookbook_versions'] || {}
         result = []
         filter_cookbooks(all_cookbooks_list(request), constraints, 1) do |name, versions|
           if versions.size > 0
-            cookbook = JSON.parse(get_data(request, request.rest_path[0..1] + ['cookbooks', name, versions[0]]), :create_additions => false)
+            cookbook = FFI_Yajl::Parser.parse(get_data(request, request.rest_path[0..1] + ['cookbooks', name, versions[0]]), :create_additions => false)
             result += recipe_names(name, cookbook)
           end
         end
