@@ -21,8 +21,9 @@ module ChefZero
 
       def get(request)
         orgname = request.rest_path[1]
-        result = list_data(request).map { |username| { "id" => "#{username}-#{orgname}", 'username' => username } }
-        json_response(200, result)
+        ChefZero::Endpoints::OrganizationUserBase.get(self, request) do |username|
+          { "id" => "#{username}-#{orgname}", 'username' => username }
+        end
       end
     end
   end
