@@ -1,4 +1,4 @@
-require 'json'
+require 'ffi_yajl'
 require 'chef_zero/rest_base'
 
 module ChefZero
@@ -34,7 +34,7 @@ module ChefZero
       end
 
       def get_key(contents)
-        json = JSON.parse(contents, :create_additions => false)
+        json = FFI_Yajl::Parser.parse(contents, :create_additions => false)
         identity_keys.map { |k| json[k] }.select { |v| v }.first
       end
     end
