@@ -18,6 +18,10 @@ module ChefZero
       @base_uri = value
     end
 
+    def api_version
+      @env['HTTP_X_OPS_SERVER_API_VERSION'] || 0
+    end
+
     def requestor
       @env['HTTP_X_OPS_USERID']
     end
