@@ -45,11 +45,12 @@ require 'chef_zero/endpoints/actor_endpoint'
 require 'chef_zero/endpoints/cookbooks_endpoint'
 require 'chef_zero/endpoints/cookbook_endpoint'
 require 'chef_zero/endpoints/cookbook_version_endpoint'
-require 'chef_zero/endpoints/cookbook_artifacts_cookbook_endpoint'
-require 'chef_zero/endpoints/cookbook_artifacts_cookbook_identifier'
 require 'chef_zero/endpoints/cookbook_artifacts_endpoint'
+require 'chef_zero/endpoints/cookbook_artifact_endpoint'
+require 'chef_zero/endpoints/cookbook_artifact_identifier_endpoint'
 require 'chef_zero/endpoints/containers_endpoint'
 require 'chef_zero/endpoints/container_endpoint'
+require 'chef_zero/endpoints/controls_endpoint'
 require 'chef_zero/endpoints/dummy_endpoint'
 require 'chef_zero/endpoints/data_bags_endpoint'
 require 'chef_zero/endpoints/data_bag_endpoint'
@@ -473,20 +474,25 @@ module ChefZero
         end
       end
 
-      if contents['cookbooks']
-        contents['cookbooks'].each_pair do |name_version, cookbook|
-          if name_version =~ /(.+)-(\d+\.\d+\.\d+)$/
-            cookbook_data = ChefData::CookbookData.to_hash(cookbook, $1, $2)
-          else
-            cookbook_data = ChefData::CookbookData.to_hash(cookbook, name_version)
-          end
-          raise "No version specified" if !cookbook_data[:version]
-          data_store.create_dir(['organizations', org_name, 'cookbooks'], cookbook_data[:cookbook_name], :recursive)
-          data_store.set(['organizations', org_name, 'cookbooks', cookbook_data[:cookbook_name], cookbook_data[:version]], FFI_Yajl::Encoder.encode(cookbook_data, :pretty => true), :create)
-          cookbook_data.values.each do |files|
-            next unless files.is_a? Array
-            files.each do |file|
-              data_store.set(['organizations', org_name, 'file_store', 'checksums', file[:checksum]], get_file(cookbook, file[:path]), :create)
+      %w(cookbooks cookbook_artifacts).each do |cookbook_type|
+        if contents[cookbook_type]
+          contents[cookbook_type].each_pair do |name_version, cookbook|
+            if cookbook_type == 'cookbook_artifacts'
+              name, dash, identifier = name_version.rpartition('-')
+              cookbook_data = ChefData::CookbookData.to_hash(cookbook, name, identifier)
+            elsif name_version =~ /(.+)-(\d+\.\d+\.\d+)$/
+              cookbook_data = ChefData::CookbookData.to_hash(cookbook, $1, $2)
+            else
+              cookbook_data = ChefData::CookbookData.to_hash(cookbook, name_version)
+            end
+            raise "No version specified" if !cookbook_data[:version]
+            data_store.create_dir(['organizations', org_name, cookbook_type], cookbook_data[:cookbook_name], :recursive)
+            data_store.set(['organizations', org_name, cookbook_type, cookbook_data[:cookbook_name], cookbook_data[:version]], FFI_Yajl::Encoder.encode(cookbook_data, :pretty => true), :create)
+            cookbook_data.values.each do |files|
+              next unless files.is_a? Array
+              files.each do |file|
+                data_store.set(['organizations', org_name, 'file_store', 'checksums', file[:checksum]], get_file(cookbook, file[:path]), :create)
+              end
             end
           end
         end
@@ -558,12 +564,13 @@ module ChefZero
         [ "/dummy", DummyEndpoint.new(self) ],
         [ "/organizations/*/clients", ActorsEndpoint.new(self) ],
         [ "/organizations/*/clients/*", ActorEndpoint.new(self) ],
+        [ "/organizations/*/controls", ControlsEndpoint.new(self) ],
         [ "/organizations/*/cookbooks", CookbooksEndpoint.new(self) ],
         [ "/organizations/*/cookbooks/*", CookbookEndpoint.new(self) ],
         [ "/organizations/*/cookbooks/*/*", CookbookVersionEndpoint.new(self) ],
         [ "/organizations/*/cookbook_artifacts", CookbookArtifactsEndpoint.new(self) ],
-        [ "/organizations/*/cookbook_artifacts/*", CookbookArtifactsCookbookEndpoint.new(self) ],
-        [ "/organizations/*/cookbook_artifacts/*/*", CookbookArtifactsCookbookIdentifierEndpoint.new(self) ],
+        [ "/organizations/*/cookbook_artifacts/*", CookbookArtifactEndpoint.new(self) ],
+        [ "/organizations/*/cookbook_artifacts/*/*", CookbookArtifactIdentifierEndpoint.new(self) ],
         [ "/organizations/*/data", DataBagsEndpoint.new(self) ],
         [ "/organizations/*/data/*", DataBagEndpoint.new(self) ],
         [ "/organizations/*/data/*/*", DataBagItemEndpoint.new(self) ],
